pywr.parameters.HydropowerTargetParameter — Pywr 0.5dev documentation

# pywr.parameters.HydropowerTargetParameter

class `pywr.parameters.` `HydropowerTargetParameter`

  A parameter that returns flow from a hydropower generation target.

  This parameter calculates the flow required to generate a particular hydropower production target. It is intended to be used on a node representing a turbine where a particular production target is required each time-step.

  Parameters: | target : Parameter instance Hydropower production target. Units should be in units of energy per day. water_elevation_parameter : Parameter instance (default=None) Elevation of water entering the turbine. The difference of this value with the turbine_elevation gives the working head of the turbine. max_flow : Parameter instance (default=None) Upper bounds on the calculated flow. If set the flow returned by this parameter is at most the value of the max_flow parameter. min_flow : Parameter instance (default=None) Lower bounds on the calculated flow. If set the flow returned by this parameter is at least the value of the min_flow parameter. min_head : double (default=0.0) Minimum head for flow to occur. If actual head is less than this value zero flow is returned. turbine_elevation : double Elevation of the turbine itself. The difference between the water_elevation and this value gives the working head of the turbine. efficiency : float (default=1.0) The efficiency of the turbine. density : float (default=1000.0) The density of water. flow_unit_conversion : float (default=1.0) A factor used to transform the units of flow to be compatible with the equation here. This should convert flow to units of \(m^3/day\) energy_unit_conversion : float (default=1e-6) A factor used to transform the units of total energy. Defaults to 1e-6 to return \(MJ\).

  See also

  `pywr.recorders.TotalHydroEnergyRecorder`, `pywr.recorders.HydropowerRecorder`

  Notes

  The inverse hydropower calculation uses the following equation.

  \[q = \frac{P}{\rho * g * \delta H}\]

  The energy rate in should be converted to units of energy per day. The returned flow rate in should is converted from units of \(m^3\) per day to those used by the model using the flow_unit_conversion parameter.

  Head is calculated from the given water_elevation_parameter and turbine_elevation value. If water elevation is given then head is the difference in elevation between the water and the turbine. If water elevation parameter is None then the head is simply the turbine elevation.

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` |

  Attributes

  `children` |
  `comment` |
  `density` |
  `double_size` |
  `efficiency` |
  `energy_unit_conversion` |
  `flow_unit_conversion` |
  `integer_size` |
  `is_variable` |
  `max_flow` |
  `min_flow` |
  `min_head` |
  `model` |
  `name` |
  `parents` |
  `size` |
  `target` |
  `turbine_elevation` |
  `water_elevation_parameter` |